import sys

from asciimol.app.asciimol import AsciiMol

if __name__ == "__main__":
    sys.exit(AsciiMol().run())
